Skip navigation links
  • Overview
  • Package
  • Class
  • Use
  • Tree
  • Deprecated
  • Index
  • Help

Deprecated API

Contents

  • Terminally Deprecated
  • Classes
  • Fields
  • Methods
  • Constructors
  • Annotation Interface Elements
  • Terminally Deprecated Elements
    Element
    Description
    io.javaoperatorsdk.operator.api.config.BaseConfigurationService.createIfNeeded()
    This method was meant to allow subclasses to prevent automatic creation of the configuration when not found. This functionality is now removed, if you want to be able to prevent automated, on-demand creation of a reconciler's configuration, please use the AbstractConfigurationService implementation instead as base for your extension.
    io.javaoperatorsdk.operator.api.config.ConfigurationService.defaultNonSSAResource()
    Use ConfigurationService.defaultNonSSAResources() instead
    io.javaoperatorsdk.operator.api.config.ControllerConfiguration.triggerReconcilerOnAllEvent()
    use ControllerConfiguration.triggerReconcilerOnAllEvents() instead
    io.javaoperatorsdk.operator.api.config.ControllerConfigurationOverrider.withTriggerReconcilerOnAllEvent(boolean)
    use ControllerConfigurationOverrider.withTriggerReconcilerOnAllEvents(boolean) instead
    io.javaoperatorsdk.operator.api.config.informer.Informer.ghostResourceCacheCheckInterval()
    Ghost resource checking is now triggered by the informer's onList callback. This setting is no longer used.
    io.javaoperatorsdk.operator.api.config.informer.InformerConfiguration.Builder.withGhostResourceCacheCheckInterval(Duration)
    io.javaoperatorsdk.operator.api.config.informer.InformerEventSourceConfiguration.Builder.withGhostResourceCacheCheckInterval(Duration)
    io.javaoperatorsdk.operator.api.config.LeaderElectionConfiguration(String)
    Use LeaderElectionConfigurationBuilder instead
    io.javaoperatorsdk.operator.api.config.LeaderElectionConfiguration(String, String)
    Use LeaderElectionConfigurationBuilder instead
    io.javaoperatorsdk.operator.api.config.LeaderElectionConfiguration(String, String, String)
    Use LeaderElectionConfigurationBuilder instead
    io.javaoperatorsdk.operator.api.config.LeaderElectionConfiguration(String, String, Duration, Duration, Duration)
    Use LeaderElectionConfigurationBuilder instead
    io.javaoperatorsdk.operator.api.config.LeaderElectionConfigurationBuilder.withExitOnStopLeading(boolean)
    Use LeaderElectionConfigurationBuilder.buildForTest(boolean) instead as setting this to false should only be used for testing purposes
    io.javaoperatorsdk.operator.api.reconciler.Constants.DEFAULT_GHOST_RESOURCE_CHECK_INTERVAL
    io.javaoperatorsdk.operator.api.reconciler.Constants.DEFAULT_GHOST_RESOURCE_CHECK_INTERVAL_MILLIS
    io.javaoperatorsdk.operator.api.reconciler.ControllerConfiguration.triggerReconcilerOnAllEvent()
    use ControllerConfiguration.triggerReconcilerOnAllEvents() instead
    io.javaoperatorsdk.operator.api.reconciler.PrimaryUpdateAndCacheUtils
    Use Context.resourceOperations() that contains the more efficient up-to-date versions of methods.
    io.javaoperatorsdk.operator.health.InformerHealthIndicator.isWatching()
    this method is not suitable for health check, it is expected that the watches sometimes fail.
    io.javaoperatorsdk.operator.Operator.installShutdownHook(Duration)
    Use Operator.installShutdownHook() instead
    io.javaoperatorsdk.operator.processing.event.source.informer.ManagedInformerEventSource.getCachedValue(ResourceID)
    Use ManagedInformerEventSource.get(ResourceID) instead.
    io.javaoperatorsdk.operator.processing.event.source.informer.Mappers.fromOwnerReferences(HasMetadata)
    use Mappers.fromOwnerReferences(Class)
    io.javaoperatorsdk.operator.processing.event.source.informer.Mappers.fromOwnerReferences(HasMetadata, boolean)
    use Mappers.fromOwnerReferences(Class,boolean)
    io.javaoperatorsdk.operator.processing.retry.GenericRetry.DEFAULT
    use GenericRetry.defaultLimitedExponentialRetry() instead this instance. Since GenericRetry is mutable, singleton is problematic.
  • Deprecated Classes
    Class
    Description
    io.javaoperatorsdk.operator.api.reconciler.PrimaryUpdateAndCacheUtils
    Use Context.resourceOperations() that contains the more efficient up-to-date versions of methods.
  • Deprecated Fields
    Field
    Description
    io.javaoperatorsdk.operator.api.reconciler.Constants.DEFAULT_GHOST_RESOURCE_CHECK_INTERVAL
    io.javaoperatorsdk.operator.api.reconciler.Constants.DEFAULT_GHOST_RESOURCE_CHECK_INTERVAL_MILLIS
    io.javaoperatorsdk.operator.processing.retry.GenericRetry.DEFAULT
    use GenericRetry.defaultLimitedExponentialRetry() instead this instance. Since GenericRetry is mutable, singleton is problematic.
  • Deprecated Methods
    Method
    Description
    io.javaoperatorsdk.operator.api.config.BaseConfigurationService.createIfNeeded()
    This method was meant to allow subclasses to prevent automatic creation of the configuration when not found. This functionality is now removed, if you want to be able to prevent automated, on-demand creation of a reconciler's configuration, please use the AbstractConfigurationService implementation instead as base for your extension.
    io.javaoperatorsdk.operator.api.config.ConfigurationService.defaultNonSSAResource()
    Use ConfigurationService.defaultNonSSAResources() instead
    io.javaoperatorsdk.operator.api.config.ControllerConfiguration.triggerReconcilerOnAllEvent()
    use ControllerConfiguration.triggerReconcilerOnAllEvents() instead
    io.javaoperatorsdk.operator.api.config.ControllerConfigurationOverrider.withTriggerReconcilerOnAllEvent(boolean)
    use ControllerConfigurationOverrider.withTriggerReconcilerOnAllEvents(boolean) instead
    io.javaoperatorsdk.operator.api.config.informer.Informer.ghostResourceCacheCheckInterval()
    Ghost resource checking is now triggered by the informer's onList callback. This setting is no longer used.
    io.javaoperatorsdk.operator.api.config.informer.InformerConfiguration.Builder.withGhostResourceCacheCheckInterval(Duration)
    io.javaoperatorsdk.operator.api.config.informer.InformerEventSourceConfiguration.Builder.withGhostResourceCacheCheckInterval(Duration)
    io.javaoperatorsdk.operator.api.config.LeaderElectionConfigurationBuilder.withExitOnStopLeading(boolean)
    Use LeaderElectionConfigurationBuilder.buildForTest(boolean) instead as setting this to false should only be used for testing purposes
    io.javaoperatorsdk.operator.api.reconciler.ControllerConfiguration.triggerReconcilerOnAllEvent()
    use ControllerConfiguration.triggerReconcilerOnAllEvents() instead
    io.javaoperatorsdk.operator.health.InformerHealthIndicator.isWatching()
    this method is not suitable for health check, it is expected that the watches sometimes fail.
    io.javaoperatorsdk.operator.Operator.installShutdownHook(Duration)
    Use Operator.installShutdownHook() instead
    io.javaoperatorsdk.operator.processing.event.source.informer.ManagedInformerEventSource.getCachedValue(ResourceID)
    Use ManagedInformerEventSource.get(ResourceID) instead.
    io.javaoperatorsdk.operator.processing.event.source.informer.Mappers.fromOwnerReferences(HasMetadata)
    use Mappers.fromOwnerReferences(Class)
    io.javaoperatorsdk.operator.processing.event.source.informer.Mappers.fromOwnerReferences(HasMetadata, boolean)
    use Mappers.fromOwnerReferences(Class,boolean)
  • Deprecated Constructors
    Constructor
    Description
    io.javaoperatorsdk.operator.api.config.LeaderElectionConfiguration(String)
    Use LeaderElectionConfigurationBuilder instead
    io.javaoperatorsdk.operator.api.config.LeaderElectionConfiguration(String, String)
    Use LeaderElectionConfigurationBuilder instead
    io.javaoperatorsdk.operator.api.config.LeaderElectionConfiguration(String, String, String)
    Use LeaderElectionConfigurationBuilder instead
    io.javaoperatorsdk.operator.api.config.LeaderElectionConfiguration(String, String, Duration, Duration, Duration)
    Use LeaderElectionConfigurationBuilder instead
    io.javaoperatorsdk.operator.api.config.LeaderElectionConfiguration(String, String, Duration, Duration, Duration, String, LeaderCallbacks, boolean)
    Use LeaderElectionConfigurationBuilder instead
  • Deprecated Annotation Interface Elements
    Annotation Interface Element
    Description
    io.javaoperatorsdk.operator.api.config.informer.Informer.ghostResourceCacheCheckInterval()
    Ghost resource checking is now triggered by the informer's onList callback. This setting is no longer used.
    io.javaoperatorsdk.operator.api.reconciler.ControllerConfiguration.triggerReconcilerOnAllEvent()
    use ControllerConfiguration.triggerReconcilerOnAllEvents() instead

Copyright © 2026. All rights reserved.