Deprecated API
Contents
-
Terminally Deprecated ElementsElementDescriptionUse
ConfigurationService.defaultNonSSAResources()insteadGhost resource checking is now triggered by the informer's onList callback. This setting is no longer used.UseLeaderElectionConfigurationBuilderinsteadUseLeaderElectionConfigurationBuilderinsteadUseLeaderElectionConfigurationBuilderinsteadUseLeaderElectionConfigurationBuilderinsteadUseLeaderElectionConfigurationBuilder.buildForTest(boolean)instead as setting this to false should only be used for testing purposesUseContext.resourceOperations()that contains the more efficient up-to-date versions of methods.this method is not suitable for health check, it is expected that the watches sometimes fail.UseOperator.installShutdownHook()insteadUseManagedInformerEventSource.get(ResourceID)instead.useGenericRetry.defaultLimitedExponentialRetry()instead this instance. Since GenericRetry is mutable, singleton is problematic.
-
Deprecated ClassesClassDescriptionUse
Context.resourceOperations()that contains the more efficient up-to-date versions of methods.
-
Deprecated FieldsFieldDescriptionuse
GenericRetry.defaultLimitedExponentialRetry()instead this instance. Since GenericRetry is mutable, singleton is problematic.
-
Deprecated MethodsMethodDescriptionThis method was meant to allow subclasses to prevent automatic creation of the configuration when not found. This functionality is now removed, if you want to be able to prevent automated, on-demand creation of a reconciler's configuration, please use the
AbstractConfigurationServiceimplementation instead as base for your extension.UseConfigurationService.defaultNonSSAResources()insteadGhost resource checking is now triggered by the informer's onList callback. This setting is no longer used.UseLeaderElectionConfigurationBuilder.buildForTest(boolean)instead as setting this to false should only be used for testing purposesthis method is not suitable for health check, it is expected that the watches sometimes fail.UseOperator.installShutdownHook()insteadUseManagedInformerEventSource.get(ResourceID)instead.
-
Deprecated ConstructorsConstructorDescriptionUse
LeaderElectionConfigurationBuilderinsteadUseLeaderElectionConfigurationBuilderinsteadUseLeaderElectionConfigurationBuilderinsteadUseLeaderElectionConfigurationBuilderinsteadUseLeaderElectionConfigurationBuilderinstead
-
Deprecated Annotation Interface ElementsAnnotation Interface ElementDescriptionGhost resource checking is now triggered by the informer's onList callback. This setting is no longer used.
AbstractConfigurationServiceimplementation instead as base for your extension.