-
Terminally Deprecated ElementsElementDescriptionUse
ConfigurationService.defaultNonSSAResources()insteaduse withParseResourceVersionsuseGenericRetry.defaultLimitedExponentialRetry()instead this instance. Since GenericRetry is mutable, singleton is problematic.
-
Deprecated FieldsFieldDescriptionuse
GenericRetry.defaultLimitedExponentialRetry()instead this instance. Since GenericRetry is mutable, singleton is problematic.
-
Deprecated MethodsMethodDescriptionThis method was meant to allow subclasses to prevent automatic creation of the configuration when not found. This functionality is now removed, if you want to be able to prevent automated, on-demand creation of a reconciler's configuration, please use the
AbstractConfigurationServiceimplementation instead as base for your extension.UseConfigurationService.defaultNonSSAResources()insteaduse withParseResourceVersions
-
Deprecated Annotation Interface ElementsAnnotation Interface ElementDescription
AbstractConfigurationServiceimplementation instead as base for your extension.